@@ -44,64 +44,6 @@ impl SudoAction {
         let opts = SudoOptions::try_parse_from(iter)?;
         opts.validate()
     }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_edit(&self) -> bool {
-        matches!(self, Self::Edit(..))
-    }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_help(&self) -> bool {
-        matches!(self, Self::Help(..))
-    }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_remove_timestamp(&self) -> bool {
-        matches!(self, Self::RemoveTimestamp(..))
-    }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_reset_timestamp(&self) -> bool {
-        matches!(self, Self::ResetTimestamp(..))
-    }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_list(&self) -> bool {
-        matches!(self, Self::List(..))
-    }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_version(&self) -> bool {
-        matches!(self, Self::Version(..))
-    }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_validate(&self) -> bool {
-        matches!(self, Self::Validate(..))
-    }
-
-    #[cfg(test)]
-    #[allow(clippy::result_large_err)]
-    pub fn try_into_run(self) -> Result<SudoRunOptions, Self> {
-        if let Self::Run(v) = self {
-            Ok(v)
-        } else {
-            Err(self)
-        }
-    }
-
-    #[cfg(test)]
-    #[must_use]
-    pub fn is_run(&self) -> bool {
-        matches!(self, Self::Run(..))
-    }
 }
 
 // sudo -h | -K | -k | -V
@@ -385,6 +327,8 @@ pub struct SudoRunOptions {
     pub askpass: bool,
     // -B
     pub bell: bool,
+    // -b
+    pub background: bool,
     // -E
     /* ignored, part of env_var_list */
     // -k
@@ -416,6 +360,7 @@ impl TryFrom<SudoOptions> for SudoRunOptions {
     fn try_from(mut opts: SudoOptions) -> Result<Self, Self::Error> {
         let askpass = mem::take(&mut opts.askpass);
         let bell = mem::take(&mut opts.bell);
+        let background = mem::take(&mut opts.background);
         let reset_timestamp = mem::take(&mut opts.reset_timestamp);
         let non_interactive = mem::take(&mut opts.non_interactive);
         let stdin = mem::take(&mut opts.stdin);
@@ -466,6 +411,7 @@ impl TryFrom<SudoOptions> for SudoRunOptions {
         Ok(Self {
             askpass,
             bell,
+            background,
             reset_timestamp,
             non_interactive,
             stdin,
@@ -487,6 +433,8 @@ struct SudoOptions {
     askpass: bool,
     // -B
     bell: bool,
+    // -b
+    background: bool,
     // -D
     chdir: Option<SudoPath>,
     // -g
@@ -698,6 +646,9 @@ impl SudoOptions {
                     "-B" | "--bell" => {
                         options.bell = true;
                     }
+                    "-b" | "--background" => {
+                        options.background = true;
+                    }
                     "-E" | "--preserve-env" => {
                         user_warn!(
                             "preserving the entire environment is not supported, '{flag}' is ignored",
@@ -878,6 +829,7 @@ fn reject_all(context: &str, opts: SudoOptions) -> Result<(), String> {
     check_options!(
         askpass,
         bell,
+        background,
         chdir,
         edit,
         group,
