@@ -18,17 +18,6 @@ pub enum Qualified<T> {
     Forbid(T) = HARDENED_ENUM_VALUE_1,
 }
 
-impl<T> Qualified<T> {
-    #[cfg(test)]
-    pub fn as_allow(&self) -> Option<&T> {
-        if let Self::Allow(v) = self {
-            Some(v)
-        } else {
-            None
-        }
-    }
-}
-
 /// Type aliases; many items can be replaced by ALL, aliases, and negated.
 pub type Spec<T> = Qualified<Meta<T>>;
 pub type SpecList<T> = Vec<Spec<T>>;
@@ -118,6 +107,7 @@ pub struct Tag {
     pub(super) env: EnvironmentControl,
     pub(super) apparmor_profile: Option<String>,
     pub(super) noexec: ExecControl,
+    pub(super) ignored: Vec<Span>,
 }
 
 impl Tag {
@@ -172,51 +162,6 @@ pub enum Sudo {
     LineComment = HARDENED_ENUM_VALUE_4,
 }
 
-impl Sudo {
-    #[cfg(test)]
-    pub fn is_spec(&self) -> bool {
-        matches!(self, Self::Spec(..))
-    }
-
-    #[cfg(test)]
-    pub fn is_decl(&self) -> bool {
-        matches!(self, Self::Decl(..))
-    }
-
-    #[cfg(test)]
-    pub fn is_line_comment(&self) -> bool {
-        matches!(self, Self::LineComment)
-    }
-
-    #[cfg(test)]
-    pub fn is_include(&self) -> bool {
-        matches!(self, Self::Include(..))
-    }
-
-    #[cfg(test)]
-    pub fn is_include_dir(&self) -> bool {
-        matches!(self, Self::IncludeDir(..))
-    }
-
-    #[cfg(test)]
-    pub fn as_include(&self) -> &str {
-        if let Self::Include(v, _) = self {
-            v
-        } else {
-            panic!()
-        }
-    }
-
-    #[cfg(test)]
-    pub fn as_spec(&self) -> Option<&PermissionSpec> {
-        if let Self::Spec(v) = self {
-            Some(v)
-        } else {
-            None
-        }
-    }
-}
-
 /// grammar:
 /// ```text
 /// identifier = name
@@ -388,25 +333,6 @@ impl Parse for MetaOrTag {
         };
 
         let result: Modifier = match keyword.as_str() {
-            // we do not support this, and that should make sudo-rs "fail safe"
-            "INTERCEPT" => unrecoverable!(
-                pos = start_pos,
-                stream,
-                "INTERCEPT is not supported by sudo-rs"
-            ),
-            // this is less fatal
-            "LOG_INPUT" | "NOLOG_INPUT" | "LOG_OUTPUT" | "NOLOG_OUTPUT" | "MAIL" | "NOMAIL"
-            | "FOLLOW" => {
-                eprintln_ignore_io_error!(
-                    "sudo-rs: {} tags in the sudoers policy are ignored",
-                    keyword.as_str()
-                );
-                switch(|_| {})?
-            }
-
-            // 'NOFOLLOW' and 'NOINTERCEPT' are the default behaviour.
-            "NOFOLLOW" | "NOINTERCEPT" => switch(|_| {})?,
-
             "EXEC" => switch(|tag| tag.noexec = ExecControl::Exec)?,
             "NOEXEC" => switch(|tag| tag.noexec = ExecControl::Noexec)?,
 
@@ -420,18 +346,35 @@ impl Parse for MetaOrTag {
                 let path: ChDir = expect_nonterminal(stream)?;
                 Box::new(move |tag| tag.cwd = Some(path.clone()))
             }
+
             // we do not support these, and that should make sudo-rs "fail safe"
-            spec @ ("CHROOT" | "TIMEOUT" | "NOTBEFORE" | "NOTAFTER") => unrecoverable!(
-                pos = start_pos,
-                stream,
-                "{spec} is not supported by sudo-rs"
-            ),
+            spec @ ("INTERCEPT" | "CHROOT" | "TIMEOUT" | "NOTBEFORE" | "NOTAFTER") => {
+                unrecoverable!(
+                    pos = start_pos,
+                    stream,
+                    "{spec} is not supported by sudo-rs"
+                )
+            }
             "ROLE" | "TYPE" => unrecoverable!(
                 pos = start_pos,
                 stream,
                 "SELinux role based access control is not yet supported by sudo-rs"
             ),
 
+            // this is less fatal
+            "LOG_INPUT" | "NOLOG_INPUT" | "LOG_OUTPUT" | "NOLOG_OUTPUT" | "MAIL" | "NOMAIL"
+            | "FOLLOW" => {
+                let ignored_location = Span {
+                    start: start_pos,
+                    end: stream.get_pos(),
+                };
+                expect_syntax(':', stream)?;
+                Box::new(move |tag| tag.ignored.push(ignored_location))
+            }
+
+            // 'NOFOLLOW' and 'NOINTERCEPT' are the default behaviour.
+            "NOFOLLOW" | "NOINTERCEPT" => switch(|_| {})?,
+
             "APPARMOR_PROFILE" => {
                 expect_syntax('=', stream)?;
                 let StringParameter(profile) = expect_nonterminal(stream)?;
