@@ -40,7 +40,7 @@ fn prompts_for_password() {
     let diagnostic = if sudo_test::is_original_sudo() {
         "a password is required"
     } else {
-        "incorrect authentication attempt"
+        "A terminal is required to authenticate"
     };
     assert_contains!(output.stderr(), diagnostic);
 }
